Package: CENTREannotation
Title: Hub package for the annotation data of CENTRE (GENCODE v40 and
        SCREEN v3)
Version: 0.99.1
Authors@R: c(person(given = "Sara", family = "Lopez Ruiz de Vargas",
    email = "lopez_s@molgen.mpg.de",
	  role = c("aut", "cre"),
		comment = c(ORCID = "0000-0002-1290-4774")))
Description: This is an AnnotationHub package for the CENTRE Bioconductor 
    software package. It contains the GENCODE version 40 annotation and ENCODE 
    Registry of candidate cis-regulatory elements (cCREs) version 3. All 
    for Human hg38 genome.
License: Artistic-2.0
Encoding: UTF-8
Roxygen: list(markdown = TRUE)
RoxygenNote: 7.3.2
biocViews: AnnotationData, AnnotationHub
Depends: R (>= 4.5.0)
Imports: AnnotationHub, RSQLite, DBI, BiocGenerics, methods
VignetteBuilder: knitr
Suggests: knitr, rmarkdown, testthat, BiocStyle
URL: https://github.com/slrvv/CENTREannotation
BugReports: https://github.com/slrvv/CENTREannotation/issues
git_url: https://git.bioconductor.org/packages/CENTREannotation
git_branch: devel
git_last_commit: 6397f51
git_last_commit_date: 2025-08-04
Repository: Bioconductor 3.22
Date/Publication: 2025-08-06
NeedsCompilation: no
Packaged: 2025-08-06 10:31:45 UTC; biocbuild
Author: Sara Lopez Ruiz de Vargas [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-1290-4774>)
Maintainer: Sara Lopez Ruiz de Vargas <lopez_s@molgen.mpg.de>
