# Generated by roxygen2: do not edit by hand

export(fetch_data)
export(tables)
exportClasses(CENTREannotDb)
import(AnnotationHub)
import(BiocGenerics)
importClassesFrom(DBI,DBIConnection)
importFrom(DBI,dbConnect)
importFrom(DBI,dbDisconnect)
importFrom(DBI,dbDriver)
importFrom(DBI,dbGetQuery)
importFrom(DBI,dbIsValid)
importFrom(DBI,dbListTables)
importFrom(RSQLite,SQLITE_RO)
importFrom(methods,.hasSlot)
importFrom(methods,is)
importFrom(methods,new)
